%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%define vnc_version 1.0.0

Name: 		x11-proto-devel
Summary:        Xorg X11 protocol specification headers
Version:        2024.1
Release:        %mkrel 9
Group:          Development/X11
License:        MIT
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/archive/individual/proto/xorgproto-%{version}.tar.xz
# FIXME: to be split:
Source31:       https://xf4vnc.sf.net/vncproto-%{vnc_version}.tar.bz2
BuildArch:      noarch

BuildRequires:  meson >= 0.43
BuildRequires:  x11-util-macros >= 1.0.1

%if !%{bootstrap}
# For docs:
BuildRequires:  docbook-dtd412-xml
BuildRequires:  docbook-dtd45-xml
BuildRequires:  docbook-style-xsl
BuildRequires:  asciidoc
BuildRequires:  xmlto
BuildRequires:  x11-sgml-doctools
%endif

BuildRequires:  python3

%description
X.Org X11 Protocol headers.

#-----------------------------------------------------------

%package -n x11-proto-doc

Summary:        Documentation for the X11 protocol and extensions
Group:          Development/X11
BuildArch:      noarch

%description -n x11-proto-doc
Documentation for the X11 protocol and extensions.

#-----------------------------------------------------------

%prep
%setup -q -n xorgproto-%version -a31

%build
%meson -Dlegacy=true
%meson_build

# vncproto is from cvs
pushd vncproto-*
aclocal
automake -a -c
autoconf
popd

for dir in vnc*/; do
pushd $dir
sed -i -e 's,^\(pkgconfigdir =\).*,\1 ${datadir}/pkgconfig,' Makefile.am
autoreconf -vfi
%configure --without-fop --build=%{_build}
%make_build
popd
done

%install
%meson_install
for dir in vnc*/; do
    if [ -d $dir ]; then
	pushd $dir
	%make_install
	popd
    fi
done

# refer to https://gitlab.freedesktop.org/xorg/proto/xorgproto/issues/10
# These headers refer to libX11 types and don't belong in this package.
# libX11 and libXvMC have been updated to supply these headers themselves
# now, so these are only useful for building older versions of those libraries.
# So let's drop conflicting files (mga#26176) as we build with "legacy" turned on:

# now in libx11 since release 1.6.9
rm -rf %{buildroot}%{_includedir}/X11/extensions/XKBgeom.h
# now in libXvMC since release 1.0.12
rm -rf %{buildroot}%{_includedir}/X11/extensions/vldXvMC.h

rm -rf %{buildroot}%{_datadir}/doc/xorgproto/*.txt
rm -rf %{buildroot}%{_datadir}/doc/xorgproto/PM_spec

%files
%{_includedir}/GL/glx*
%dir %{_includedir}/GL/internal
%{_includedir}/GL/internal/*
%{_includedir}/X11/*.h
%{_includedir}/X11/dri/*
%{_includedir}/X11/extensions/*
%{_includedir}/X11/fonts/*
%{_includedir}/X11/PM/*
%{_datadir}/pkgconfig/*.pc

%files -n x11-proto-doc
%doc *.txt PM_spec


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 2024.1-9.mga10
+ Revision: 2236101
- Mageia 10 Mass Rebuild

* Fri Feb 21 2025 neoclust <neoclust> 2024.1-8.mga10
+ Revision: 2150215
- Rebuild against python 3.13

* Fri Jan 03 2025 daviddavid <daviddavid> 2024.1-7.mga10
+ Revision: 2135188
- own include dir

* Tue Apr 02 2024 tv <tv> 2024.1-6.mga10
+ Revision: 2053998
- xorgproto 2024.1

* Tue Dec 19 2023 papoteur <papoteur> 2023.2-6.mga10
+ Revision: 2019409
- Mass Rebuild - Python 3.12

* Thu Dec 07 2023 wally <wally> 2023.2-5.mga10
+ Revision: 2014772
- rebuild for py3.12

* Tue Oct 17 2023 daviddavid <daviddavid> 2023.2-4.mga10
+ Revision: 1998224
- remove xcb-proto now splitted in its own pkg

* Tue Oct 17 2023 daviddavid <daviddavid> 2023.2-3.mga10
+ Revision: 1997883
- update xcb-proto to 1.16.0

* Thu Sep 21 2023 tv <tv> 2023.2-2.mga10
+ Revision: 1989077
- xorgproto 2023.2

* Wed Nov 02 2022 luigiwalser <luigiwalser> 2022.2-2.mga9
+ Revision: 1901812
- xcb-proto 1.15.2

* Sat Sep 24 2022 luigiwalser <luigiwalser> 2022.2-1.mga9
+ Revision: 1891878
- 2022.2

* Tue Apr 26 2022 luigiwalser <luigiwalser> 2022.1-1.mga9
+ Revision: 1854463
- 2022.1

* Thu Mar 24 2022 umeabot <umeabot> 2021.5-3.mga9
+ Revision: 1824647
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 2021.5-2.mga9
+ Revision: 1772020
- rebuild for python3.10

* Mon Nov 01 2021 tv <tv> 2021.5-1.mga9
+ Revision: 1753540
- xorgproto 2021.5

* Mon Jun 14 2021 tv <tv> 2021.4.99.2-1.mga9
+ Revision: 1730690
- Prerelease for inputproto snapshot

* Sun Mar 14 2021 wally <wally> 2021.3-2.mga9
+ Revision: 1702578
- rebuild for python 3.9

* Sun Feb 28 2021 tv <tv> 2021.3-1.mga9
+ Revision: 1693703
- xorgproto 2021.3

* Sat Oct 10 2020 tv <tv> 2020.1-2.mga8
+ Revision: 1633070
- xcb-proto-1.14.1

* Sat Apr 18 2020 tv <tv> 2020.1-1.mga8
+ Revision: 1568971
- 2020.1
+ danf <danf>
- Switch URLs from http: to https:

* Wed Mar 04 2020 tv <tv> 2019.2-4.mga8
+ Revision: 1553627
- xcb-proto 1.14

* Thu Feb 20 2020 umeabot <umeabot> 2019.2-3.mga8
+ Revision: 1547374
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 2019.2-2.mga8
+ Revision: 1488058
- drop conflicting header files with libx11-devel and libxvmc-devel pkgs (mga#26176)
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 22 2019 tv <tv> 2019.2-1.mga8
+ Revision: 1455205
- new release

* Wed Sep 04 2019 tv <tv> 2019.1-3.mga8
+ Revision: 1437082
- rebuild for python 3.8

* Sun Sep 01 2019 wally <wally> 2019.1-2.mga8
+ Revision: 1436084
- switch to python3

* Wed Jul 03 2019 tv <tv> 2019.1-1.mga8
+ Revision: 1417960
- new release

* Thu Apr 18 2019 umeabot <umeabot> 2018.4-4.mga7
+ Revision: 1392979
- Rebuild with meson 0.50.1

* Fri Sep 21 2018 umeabot <umeabot> 2018.4-3.mga7
+ Revision: 1292154
- Mageia 7 Mass Rebuild

* Fri Mar 09 2018 tv <tv> 2018.4-2.mga7
+ Revision: 1207521
- xcb-proto 1.13 (to be split...)
- new release

* Wed Feb 21 2018 tv <tv> 2018.3-3.mga7
+ Revision: 1203970
- enable legacy specs as we still have eg: a couple libxp users

* Wed Feb 21 2018 tv <tv> 2018.3-2.mga7
+ Revision: 1203919
- Switch to meson (note that using -Dlegacy=true would bring back fontcache as
  well as some proto we never shiped)

* Wed Feb 21 2018 tv <tv> 2018.3-1.mga7
+ Revision: 1203909
- Switch to merged protocol headers
- Drop evie & xprint headers
- keep vnc & xcb proto (to be split)
- bug: fontcache is not installed

* Sat Sep 09 2017 tv <tv> 7.7-29.mga7
+ Revision: 1152278
- fix build with latet rpm (bogus usage of %%setup -b instead of -a)

* Wed Feb 22 2017 wally <wally> 7.7-28.mga6
+ Revision: 1087415
- move pkgconfig .pc files to noarch location
- drop some ancient Mdv era conflicts

* Fri Jan 27 2017 tv <tv> 7.7-27.mga6
+ Revision: 1083576
- drop merged patch
- presentproto 1.1

* Sat Oct 15 2016 tv <tv> 7.7-26.mga6
+ Revision: 1060924
- use %%configure2_5x with --build=%%{_build} instead of %%old_configure

* Tue Oct 04 2016 tv <tv> 7.7-25.mga6
+ Revision: 1058660
- xproto 7.0.31

* Fri May 27 2016 tv <tv> 7.7-24.mga6
+ Revision: 1018867
- xproto 7.0.29

* Wed May 25 2016 luigiwalser <luigiwalser> 7.7-23.mga6
+ Revision: 1018527
- xcb-proto 1.12

* Fri Apr 08 2016 tv <tv> 7.7-22.mga6
+ Revision: 999353
- inputproto 2.3.2

* Sat Mar 12 2016 tv <tv> 7.7-21.mga6
+ Revision: 989388
- update videoproto
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Nov 10 2015 tv <tv> 7.7-19.mga6
+ Revision: 900993
- xproto 7.0.28

* Tue Sep 29 2015 tv <tv> 7.7-18.mga6
+ Revision: 885017
- use %%old_configure
- make it noarch thus fixing empty debuginfo

* Fri Jul 03 2015 tv <tv> 7.7-17.mga6
+ Revision: 849653
- xproto 7.0.28

* Sun Jun 21 2015 tv <tv> 7.7-16.mga6
+ Revision: 837501
- kbproto 1.0.7
- xproto 7.0.27

* Sat Jun 20 2015 tv <tv> 7.7-15.mga6
+ Revision: 835789
- update for xserver 1.17

* Sat Nov 29 2014 sander85 <sander85> 7.7-14.mga6
+ Revision: 799881
- Drop unneeded BR on fop

* Wed Oct 15 2014 umeabot <umeabot> 7.7-13.mga5
+ Revision: 742745
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 7.7-12.mga5
+ Revision: 690521
- Mageia 5 Mass Rebuild

* Thu Aug 21 2014 blino <blino> 7.7-11.mga5
+ Revision: 666114
- backport upstream presentproto patch to fix client libs on 64-bit machines

* Mon Aug 04 2014 blino <blino> 7.7-10.mga5
+ Revision: 659672
- xcb-proto 1.11
- buildrequire asciidoc to build inputproto doc
- remove docbook5-style-xsl buildrequire (a local build succeeds without it)

* Mon Jun 02 2014 tv <tv> 7.7-9.mga5
+ Revision: 630590
- inputproto 2.3.1
+ pterjan <pterjan>
- Rebuild for new Python

* Mon Apr 14 2014 tv <tv> 7.7-7.mga5
+ Revision: 614257
- xproto 7.0.26

* Mon Apr 14 2014 tv <tv> 7.7-6.mga5
+ Revision: 614145
- fonts-proto 2.1.3

* Tue Feb 04 2014 tv <tv> 7.7-5.mga5
+ Revision: 581923
- adjust file list
- do package present proto

* Tue Feb 04 2014 tv <tv> 7.7-4.mga5
+ Revision: 581723
- glproto 1.4.17

* Tue Feb 04 2014 tv <tv> 7.7-3.mga5
+ Revision: 581613
- adjust file list
- dri3proto 1.0
- xcb-proto 1.10
- xextproto 7.3.0
- xproto 7.0.25

* Sat Oct 19 2013 umeabot <umeabot> 7.7-3.mga4
+ Revision: 530656
- Mageia 4 Mass Rebuild

* Sat Jul 27 2013 tv <tv> 7.7-2.mga4
+ Revision: 458822
- videoproto 2.3.2

* Thu May 23 2013 tv <tv> 7.7-1.mga4
+ Revision: 425285
- adjust file list
- bump to 7.7
- inputproto 2.3
- xproto-7.0.24
- bump to 7.7
- inputproto 2.3
- xproto-7.0.24

* Fri Feb 08 2013 luigiwalser <luigiwalser> 7.6-24.mga3
+ Revision: 397212
- remove obsolete pre script

* Mon Jan 14 2013 umeabot <umeabot> 7.6-23.mga3
+ Revision: 386385
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 05 2012 tv <tv> 7.6-22.mga3
+ Revision: 302964
- xcb-proto 1.8

* Mon Jul 23 2012 tv <tv> 7.6-21.mga3
+ Revision: 273822
- gl 1.4.16
- randr 1.4.0

* Thu Jul 12 2012 tv <tv> 7.6-20.mga3
+ Revision: 270197
- dri2proto 2.8

* Tue May 29 2012 tv <tv> 7.6-19.mga3
+ Revision: 249368
- bigreqs_version 1.1.1
- fonts_version 2.1.1
- record_version 1.14.1
- scrnsaver_version 1.2.1
- xcmisc_version 1.2.1
- xext_version 7.2.0
- xproto_version 7.0.22

* Mon May 28 2012 colin <colin> 7.6-18.mga3
+ Revision: 248390
- Bump inputproto to 2.2

* Wed Feb 01 2012 tv <tv> 7.6-17.mga2
+ Revision: 203747
- input_version 2.1

* Tue Jan 31 2012 tv <tv> 7.6-16.mga2
+ Revision: 203676
- reenable doc

* Sun Jan 29 2012 tv <tv> 7.6-15.mga2
+ Revision: 203072
- glproto-1.4.15
- temporary disable docs

* Sat Jan 28 2012 fwang <fwang> 7.6-14.mga2
+ Revision: 202575
- disable fop build
- add ore br
+ tv <tv>
- BR docbook-style-xsl
- update xcb-proto to 1.7
- make the huge doc subpackage be noarch

* Thu Jun 30 2011 tv <tv> 7.6-12.mga2
+ Revision: 116233
- update file list
- glproto-1.4.14
- dri2proto-2.6

* Wed Jun 29 2011 tv <tv> 7.6-11.mga2
+ Revision: 116153
- xproto-7.0.22

* Fri Jun 17 2011 tv <tv> 7.6-10.mga2
+ Revision: 108553
- fix file list
- inputproto-2.0.2
- resourceproto-1.2.0

* Tue Apr 12 2011 tv <tv> 7.6-9.mga1
+ Revision: 83565
- applewmproto-1.4.2
- fixesproto-5.0

* Fri Apr 01 2011 tv <tv> 7.6-8.mga1
+ Revision: 79629
- xproto 7.0.21

* Tue Mar 01 2011 tv <tv> 7.6-7.mga1
+ Revision: 62134
- xextproto-7.2.0

* Fri Jan 28 2011 dmorgan <dmorgan> 7.6-6.mga1
+ Revision: 43007
- Disable bootstrap
+ rtp <rtp>
- disable fop on arm/mips as it's using java

* Mon Jan 17 2011 blino <blino> 7.6-5.mga1
+ Revision: 20920
- build with bootstrap again (and with new python)
- rebuild without bootstrap

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-4.mga1
+ Revision: 6363
- Remove workaround

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-3.mga1
+ Revision: 6333
- Fix else statement
- Bump release
- Enable the provides for the moment

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-2.mga1
+ Revision: 6322
- Rebuild

* Tue Jan 11 2011 dmorgan <dmorgan> 7.6-1.mga1
+ Revision: 6266
- Fix file List
- Fix file List
- Do not build docs for now
- imported package x11-proto-devel


* Thu Jan 06 2011 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 7.6-1mdv2011.0
+ Revision: 629034
- Use a configure macro instead of re-defining it
- New dmxproto version:         2.3.1
- New evieext version:          1.1.1
- New printproto version:       1.0.5
- New xf86driproto version:     2.1.1
- New xf86vidmodeproto version: 2.3.1
- New xineramaproto version:    1.2.1
- Don't ship Xprint manpage

* Thu Dec 09 2010 Thierry Vignaud <tv@mandriva.org> 7.6-0.5mdv2011.0
+ Revision: 617318
- resource_version 1.1.1
- adjust file list
- input_version 2.0.1

  + Paulo Ricardo Zanoni <pzanoni@mandriva.com>
    - Add missing BR for docs
    - Move docs to x11-proto-doc package
    - New xproto version: 7.0.20

* Sun Nov 07 2010 Thierry Vignaud <tv@mandriva.org> 7.6-0.2mdv2011.0
+ Revision: 594636
- adjust file list
- xproto 7.0.19

* Tue Nov 02 2010 Thierry Vignaud <tv@mandriva.org> 7.6-0.1mdv2011.0
+ Revision: 591818
- adjust filelist
- bump version to 7.6
- bigreqs_version 1.1.1
- composite_version 0.4.2
- damage_version 1.2.1
- fixes_version 4.1.2
- fonts_version 2.1.1
- randr_version 1.3.2
- record_version 1.14.1
- scrnsaver_version 1.2.1
- xcmisc_version 1.2.1

* Wed Aug 18 2010 Thierry Vignaud <tv@mandriva.org> 7.5-8mdv2011.0
+ Revision: 571260
- adjust filelist
- gl_version 1.4.12
- kb_version 1.0.5
- render_version 0.11.1
- video_version 2.3.1
- xext_version 7.1.2
- xproto_version 7.0.18

* Wed Jul 21 2010 Thierry Vignaud <tv@mandriva.org> 7.5-6mdv2011.0
+ Revision: 556319
- xproto 7.0.17

* Wed Feb 17 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 7.5-5mdv2010.1
+ Revision: 507005
- New dri2proto version: 2.3

* Mon Jan 11 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 7.5-4mdv2010.1
+ Revision: 489817
- New glproto version: 1.4.11
  New dri2proto version: 2.2

* Wed Dec 02 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 7.5-3mdv2010.1
+ Revision: 472610
- Update xcb-proto to 1.6

* Tue Nov 10 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 7.5-2mdv2010.1
+ Revision: 464230
- Update xproxymanagementproto to 1.0.3

* Mon Nov 09 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 7.5-1mdv2010.1
+ Revision: 463625
- Update protos for 7.5 release

* Mon Sep 28 2009 Olivier Blin <oblin@mandriva.com> 7.4-26mdv2010.0
+ Revision: 450583
- add bootstrap flag, was mentionned in the spec but not implemented
  (from Arnaud Patard)

* Tue Sep 01 2009 Thierry Vignaud <tv@mandriva.org> 7.4-25mdv2010.0
+ Revision: 423867
- update applewmproto to 1.4.1
- update bigreqsproto to 1.1.0
- update damageproto to 1.2.0
- update fontsproto to 2.1.0
- update resourceproto to 1.1.0
- update scrnsaverproto to 1.2.0
- update videoproto to 2.3.0
- update xcmiscproto to 1.2.0
- update xf86bigfontproto to 1.2.0
- update xf86driproto to 2.1.0

* Tue Jul 21 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 7.4-24mdv2010.0
+ Revision: 398282
- Revert xextproto 1.0.99.3 update: it is development stuff and breaks
  x11-server 1.6.2 build, shouldn't be pushed without updating
  x11-server to latest devel releases.

* Sun Jul 19 2009 Colin Guthrie <cguthrie@mandriva.org> 7.4-23mdv2010.0
+ Revision: 397495
- Revert back to inputproto 1.5.1 and applewmproto 1.1.1 due to upstream problems.

* Sat Jul 18 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 7.4-22mdv2010.0
+ Revision: 397093
- update applewmproto to 1.3.0
- update inputproto to 1.9.99.14

* Fri Jul 17 2009 Colin Guthrie <cguthrie@mandriva.org> 7.4-21mdv2010.0
+ Revision: 396716
- renderproto 0.11
- xextproto 7.0.99.1

* Tue Jun 30 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 7.4-20mdv2010.0
+ Revision: 391007
- update glproto to 1.4.10

* Fri Jun 19 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 7.4-19mdv2010.0
+ Revision: 387319
- update inputproto to version 1.5.1

* Mon Jun 15 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 7.4-18mdv2010.0
+ Revision: 386191
- update dri2proto to version 2.1

* Tue Jun 02 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 7.4-17mdv2010.0
+ Revision: 382314
- Update xkb-proto to 1.5

* Thu Apr 30 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 7.4-16mdv2010.0
+ Revision: 369177
- Update dri2proto to 2.0

* Fri Mar 06 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 7.4-16mdv2009.1
+ Revision: 349888
- Update randrproto to 1.3.0

* Mon Mar 02 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 7.4-15mdv2009.1
+ Revision: 347508
- Update xproto to 7.0.15 and remove patch applied upstream

* Thu Feb 26 2009 Frederic Crozat <fcrozat@mandriva.com> 7.4-14mdv2009.1
+ Revision: 345207
- Patch0 (upstream): Add XF86XK_Suspend and XF86XK_Hibernate to keysyms

* Wed Feb 25 2009 Colin Guthrie <cguthrie@mandriva.org> 7.4-13mdv2009.1
+ Revision: 344965
- Update to randrproto 1.2.99.4

* Tue Feb 17 2009 Colin Guthrie <cguthrie@mandriva.org> 7.4-12mdv2009.1
+ Revision: 341532
- Update xcb proto to 1.4

* Sat Jan 31 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 7.4-11mdv2009.1
+ Revision: 335720
- update xextproto to 7.0.5 version

* Mon Dec 29 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-10mdv2009.1
+ Revision: 321040
- Update dri2proto to 1.99.3

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 7.4-9mdv2009.1
+ Revision: 319300
- rebuild for new python

* Thu Dec 18 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-8mdv2009.1
+ Revision: 315514
- Update xextproto to 7.0.4

* Sat Dec 13 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-7mdv2009.1
+ Revision: 313923
- Update xcb to 1.3
- Update randr to 1.2.99.3

* Tue Dec 02 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-6mdv2009.1
+ Revision: 309200
- Update randrproto to 1.2.99.1

* Sat Nov 29 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-5mdv2009.1
+ Revision: 307978
- Update inputproto to 1.5.0
- Update dri2proto to snapshot for upcoming Mesa compatibility

* Thu Nov 06 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-4mdv2009.1
+ Revision: 300305
- Renable non-bootstrap version to get full pkgconfig provides

* Thu Nov 06 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-3mdv2009.1
+ Revision: 300294
- Use the bootstrap provides to allow kicking libx11 into life

* Thu Nov 06 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-2mdv2009.1
+ Revision: 300282
- Remove BR on libxau-devel as it does not seem to be needed either.
- Update xproto to 7.0.14
- Remove dependency on libxt-devel as it does not seem needed and causes a circular dep for libx11

* Mon Oct 20 2008 Colin Guthrie <cguthrie@mandriva.org> 7.4-1mdv2009.1
+ Revision: 295847
- Change package version to 7.4 to reflect Xorg 7.4 release
- Update applewm to 1.1.1
- Update input to 1.4.4
- Update xext to 7.0.3
- Update xproto to 7.0.13
- Remove input patches merged upstream

* Fri Jul 18 2008 Ander Conselvan de Oliveira <ander@mandriva.com> 7.3-6mdv2009.0
+ Revision: 238249
- Corrects python lib path.
- Add build dependency to python.
- Update xcb-proto to 1.2
  Update randrporo to 1.2.2

* Wed May 28 2008 Paulo Andrade <pcpa@mandriva.com.br> 7.3-5mdv2009.0
+ Revision: 212670
- Closes #41096 (Conflicting declarations between X11 and Qt).

* Mon Apr 14 2008 Paulo Andrade <pcpa@mandriva.com.br> 7.3-4mdv2009.0
+ Revision: 192894
- Remove xf86rushproto. The library itself is long gone,
  no reason to keep headers.
- Minor spec fix so that %%build will not give an error exit code due to
  not checking if shell glob is a directory, before attempting to chdir,
  and run %%makeinstall from it.

  + Colin Guthrie <cguthrie@mandriva.org>
    - Update xproto to 7.0.12
    - Update xf86dri to 2.0.4
    - Update print to 1.0.4
    - Update input to 1.4.3
    - Add dri2 1.1

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag
    - kill re-definition of %%buildroot on Pixel's request

  + Ademar de Souza Reis Jr <ademar@mandriva.com.br>
    - remove old glproto version from SOURCES

* Wed Nov 07 2007 Ademar de Souza Reis Jr <ademar@mandriva.com.br> 7.3-2mdv2008.1
+ Revision: 106781
- new xcb-proto upstream version: 1.1

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - update glproto

* Mon Oct 15 2007 Ademar de Souza Reis Jr <ademar@mandriva.com.br> 7.3-1mdv2008.1
+ Revision: 98599
- change version so that it reflects the x.org release, not
  the x-server version (as other distros such as fedora)
- added description

* Tue Oct 09 2007 Thierry Vignaud <tv@mandriva.org> 1.4.0-1mdv2008.1
+ Revision: 96103
- add missing file
- update inputproto, renderproto, xf86dgaproto & xproto

* Wed Jul 04 2007 Colin Guthrie <cguthrie@mandriva.org> 1.3.0-1mdv2008.0
+ Revision: 48008
- Increment version to 1.3.0 to follow xserver version
- Update compositeproto to 0.4.0


* Thu Mar 01 2007 Colin Guthrie <cguthrie@mandriva.org> 1.2.0-11mdv2007.0
+ Revision: 130270
- Update randrproto to 1.2.1

* Tue Feb 27 2007 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.2.0-10mdv2007.1
+ Revision: 126342
- adding RandR proto for the version 1.2 of the extension.
- adding the XCB proto (http://xcb.freedesktop.org)

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 1.2.0-9mdv2007.1
+ Revision: 122425
- finally fix buildrequires and enable all pkgconfig provides

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 1.2.0-8mdv2007.1
+ Revision: 122383
- add more provides before enabling the right buildrequires

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 1.2.0-7mdv2007.1
+ Revision: 122370
- temporarily add pkgconfig(xproto) by and as a provide

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 1.2.0-6mdv2007.1
+ Revision: 122369
- add buildrequires on pkgconfig to work around the fucked up build system that doesn't install the latest rpm-mandriva-setup-build

* Sun Feb 18 2007 Colin Guthrie <cguthrie@mandriva.org> 1.2.0-5mdv2007.1
+ Revision: 122352
- Update to inputproto-1.4.1 (fixes bug in DevicePresence())

* Sun Feb 18 2007 Anssi Hannula <anssi@mandriva.org> 1.2.0-4mdv2007.1
+ Revision: 122344
- rebuild to really fix pkgconfig deps

* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 1.2.0-3mdv2007.1
+ Revision: 122278
- rebuild for pkgconfig deps

* Tue Feb 06 2007 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.2.0-2mdv2007.1
+ Revision: 116839
- updated xproto to 7.0.10

* Mon Feb 05 2007 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.2.0-1mdv2007.1
+ Revision: 116414
- add missing file from new damageproto
- really add the damageproto tarball
- new damageproto version: 1.1.0
- bump package version to 1.2.0 to follow xserver version

* Tue Jan 09 2007 Colin Guthrie <cguthrie@mandriva.org> 1.0.3-4mdv2007.1
+ Revision: 106813
- Update glproto to 1.4.8 as required by Mesa 6.5.2 and Xorg Xserver 1.1.99.903

* Tue Nov 21 2006 Thierry Vignaud <tvignaud@mandriva.com> 1.0.3-3mdv2007.1
+ Revision: 85911
- update input and x proto
- sort

  + Christiaan Welvaart <cjw@daneel.dyndns.org>
    - added vnc proto for Xvnc
    - protocol headers for VNC

* Thu Aug 03 2006 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.3-1mdv2007.0
+ Revision: 42998
- new upstream kbproto version (1.0.3):
  * Always define XkbSA_XFree86Private, not only when XFree86Server is defined
- new upstream xproto version:
  * Add Braille keysyms (7.0.6)
  * Add dead_stroke keysym (7.0.7)
- rebuild to fix cooker uploading
- X11R7.1
- increment release
- rollback the glproto version as the compilation fails using the latest
  version
- Adding X.org 7.0 to the repository

  + Laurent Montel <lmontel@mandriva.com>
    - This rpm must be arch'ed (pkg-config files must be installed into /usr/libxx/pkg-config)
      => fix compile error on x86_64
    - Fix conflict on x86_64

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

